 #if !defined(MQXC_INCLUDED)           /* File not yet included?      */
   #define MQXC_INCLUDED               /* Show file now included      */
 /*********************************************************************/
 /*                                                                   */
 /*  Program name:  CMQXC                                             */
 /*                                                                   */
 /*  Description:   This file declares functions, structures, and     */
 /*                 constants for the IBM Message Queue Interface     */
 /*                 (MQI) in the PC-DOS environment.                  */
 /*                                                                   */
 /*                                                                   */
 /*  Statement:     Licensed Materials - Property of IBM              */
 /*                                                                   */
 /*                 33H2205, 5622-908                                 */ 
 /*                 (C) Copyright IBM Corp. 1995                      */ 
 /*                                                                   */
 /*                                                                   */
 /*  Status:        Version 2 Release 0.1                             */
 /*                                                                   */
 /*********************************************************************/

 #if defined(__cplusplus)
   extern "C" {
 #endif

 /*********************************************************************/
 /*  Values Related to MQCD Structure                                 */
 /*********************************************************************/

 /* Structure Version Number */
 #define MQCD_VERSION_1       1L
 #define MQCD_VERSION_2       2L
 #define MQCD_VERSION_3       3L
 #define MQCD_CURRENT_VERSION 3L

 /* Channel Type */
 #define MQCHT_SENDER    1L
 #define MQCHT_SERVER    2L
 #define MQCHT_RECEIVER  3L
 #define MQCHT_REQUESTER 4L
 #define MQCHT_ALL       5L
 #define MQCHT_CLNTCONN  6L
 #define MQCHT_SVRCONN   7L

 /* Transport Type */
 #define MQXPT_LU62    1L
 #define MQXPT_TCP     2L
 #define MQXPT_NETBIOS 3L

 /* Put Authority */
 #define MQPA_DEFAULT 1L
 #define MQPA_CONTEXT 2L

 /* Channel Data Conversion */
 #define MQCDC_SENDER_CONVERSION    1L
 #define MQCDC_NO_SENDER_CONVERSION 0L

 /* MCA Type */
 #define MQMCAT_PROCESS 1L
 #define MQMCAT_THREAD  2L


 /*********************************************************************/
 /*  Values Related to MQCXP Structure                                */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQCXP_STRUC_ID "CXP "

 /* Structure Identifier (array form) */
 #define MQCXP_STRUC_ID_ARRAY 'C','X','P',' '

 /* Structure Version Number */
 #define MQCXP_VERSION_1       1L
 #define MQCXP_VERSION_2       2L
 #define MQCXP_CURRENT_VERSION 2L

 /* Exit Response 2 */
 #define MQXR2_PUT_WITH_DEF_ACTION 0L
 #define MQXR2_PUT_WITH_DEF_USERID 1L
 #define MQXR2_PUT_WITH_MSG_USERID 2L
 #define MQXR2_USE_AGENT_BUFFER    0L
 #define MQXR2_USE_EXIT_BUFFER     4L


 /*********************************************************************/
 /*  Values Related to MQDXP Structure                                */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQDXP_STRUC_ID "DXP "

 /* Structure Identifier (array form) */
 #define MQDXP_STRUC_ID_ARRAY 'D','X','P',' '

 /* Structure Version Number */
 #define MQDXP_VERSION_1 1L

 /* Exit Response */
 #define MQXDR_OK                0L
 #define MQXDR_CONVERSION_FAILED 1L


 /*********************************************************************/
 /*  General Values Related to Exits                                  */
 /*********************************************************************/

 /* Exit Identifier */
 #define MQXT_CHANNEL_SEC_EXIT        11L
 #define MQXT_CHANNEL_MSG_EXIT        12L
 #define MQXT_CHANNEL_SEND_EXIT       13L
 #define MQXT_CHANNEL_RCV_EXIT        14L
 #define MQXT_CHANNEL_MSG_RETRY_EXIT  15L

 /* Exit Reason */
 #define MQXR_INIT     11L
 #define MQXR_TERM     12L
 #define MQXR_MSG      13L
 #define MQXR_XMIT     14L
 #define MQXR_SEC_MSG  15L
 #define MQXR_INIT_SEC 16L
 #define MQXR_RETRY    17L

 /* Exit Response */
 #define MQXCC_OK                       0L
 #define MQXCC_SUPPRESS_FUNCTION        (-1L)
 #define MQXCC_SEND_AND_REQUEST_SEC_MSG (-3L)
 #define MQXCC_SEND_SEC_MSG             (-4L)
 #define MQXCC_SUPPRESS_EXIT            (-5L)
 #define MQXCC_CLOSE_CHANNEL            (-6L)

 /* Exit User Area Value */
 #define MQXUA_NONE "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"

 /* Exit User Area Value (array form) */
 #define MQXUA_NONE_ARRAY \
     '\0','\0','\0','\0','\0','\0','\0','\0',\
     '\0','\0','\0','\0','\0','\0','\0','\0'


 /*********************************************************************/
 /*  Values Related to MQXCNVC Function                               */
 /*********************************************************************/

 /* Conversion Options */
 #define MQDCC_NONE 0L


 /*********************************************************************/
 /*  MQCD Structure                                                   */
 /*********************************************************************/

 typedef struct tagMQCD {
   MQCHAR  ChannelName[20];           /* Channel definition name */
   MQLONG  Version;                   /* Structure version number */
   MQLONG  ChannelType;               /* Channel type */
   MQLONG  TransportType;             /* Transport type */
   MQCHAR  Desc[64];                  /* Channel description */
   MQCHAR  QMgrName[48];              /* Queue-manager name */
   MQCHAR  XmitQName[48];             /* Transmission queue name */
   MQCHAR  ShortConnectionName[20];   /* First 20 characters of
                                         connection name */
   MQCHAR  MCAName[20];               /* Reserved */
   MQCHAR  ModeName[8];               /* LU6.2 Mode name */
   MQCHAR  TpName[64];                /* LU6.2 transaction program
                                         name */
   MQLONG  BatchSize;                 /* Batch size */
   MQLONG  DiscInterval;              /* Disconnect interval */
   MQLONG  ShortRetryCount;           /* Short retry count */
   MQLONG  ShortRetryInterval;        /* Short retry wait interval */
   MQLONG  LongRetryCount;            /* Long retry count */
   MQLONG  LongRetryInterval;         /* Long retry wait interval */
   MQCHAR  SecurityExit[128];         /* Channel security exit name */
   MQCHAR  MsgExit[128];              /* Channel message exit name */
   MQCHAR  SendExit[128];             /* Channel send exit name */
   MQCHAR  ReceiveExit[128];          /* Channel receive exit name */
   MQLONG  SeqNumberWrap;             /* Highest allowable message
                                         sequence number */
   MQLONG  MaxMsgLength;              /* Maximum message length */
   MQLONG  PutAuthority;              /* Put authority */
   MQLONG  DataConversion;            /* Data conversion */
   MQCHAR  SecurityUserData[32];      /* Channel security exit user
                                         data */
   MQCHAR  MsgUserData[32];           /* Channel message exit user
                                         data */
   MQCHAR  SendUserData[32];          /* Channel send exit user data */
   MQCHAR  ReceiveUserData[32];       /* Channel receive exit user
                                         data */
   MQCHAR  UserIdentifier[12];        /* User identifier */
   MQCHAR  Password[12];              /* Password */
   MQCHAR  MCAUserIdentifier[12];     /* Message channel agent user
                                         identifier */
   MQLONG  MCAType;                   /* Message channel agent type */
   MQCHAR  ConnectionName[264];       /* Connection name */
   MQCHAR  RemoteUserIdentifier[12];  /* User identifier from partner */
   MQCHAR  RemotePassword[12];        /* Password from partner */
   MQCHAR  MsgRetryExit[128];         /* Message-retry exit name */
   MQCHAR  MsgRetryUserData[32];      /* Message-retry exit user data */
   MQLONG  MsgRetryCount;             /* Number of times MCA will try to
                                         put the message after first put
                                         has failed */
   MQLONG  MsgRetryInterval;          /* Interval in milliseconds after
                                         which the put operation should
                                         be retried */
  } MQCD;
 typedef MQCD MQPOINTER PMQCD;

 #define MQCD_DEFAULT {""},\
                      MQCD_VERSION_3,\
                      MQCHT_SENDER,\
                      MQXPT_LU62,\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      50L,\
                      6000L,\
                      10L,\
                      60L,\
                      999999999L,\
                      1200L,\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      999999999L,\
                      4194304L,\
                      MQPA_DEFAULT,\
                      MQCDC_NO_SENDER_CONVERSION,\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      MQMCAT_PROCESS,\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      10L,\
                      1000L

 /*********************************************************************/
 /*  MQCXP Structure                                                  */
 /*********************************************************************/

 typedef struct tagMQCXP {
   MQCHAR4   StrucId;           /* Structure identifier */
   MQLONG    Version;           /* Structure version number */
   MQLONG    ExitId;            /* Type of exit */
   MQLONG    ExitReason;        /* Reason for invoking exit */
   MQLONG    ExitResponse;      /* Response from exit */
   MQLONG    ExitResponse2;     /* Secondary response from exit */
   MQLONG    Feedback;          /* Feedback code */
   MQLONG    MaxSegmentLength;  /* Maximum segment length */
   MQBYTE16  ExitUserArea;      /* Exit user area */
   MQCHAR32  ExitData;          /* Exit data */
   MQLONG    MsgRetryCount;     /* Number of times MCA has tried to put
                                   the message */
   MQLONG    MsgRetryInterval;  /* Interval in milliseconds after which
                                   the put operation should be
                                   retried */
   MQLONG    MsgRetryReason;    /* Reason code from previous attempt to
                                   put the message */
  } MQCXP;
 typedef MQCXP MQPOINTER PMQCXP;

 #define MQCXP_DEFAULT {MQCXP_STRUC_ID_ARRAY},\
                       MQCXP_VERSION_2,\
                       0L,\
                       0L,\
                       MQXCC_OK,\
                       MQXR2_PUT_WITH_DEF_ACTION,\
                       0L,\
                       0L,\
                       {MQXUA_NONE_ARRAY},\
                       {""},\
                       0L,\
                       0L,\
                       0L

 /*********************************************************************/
 /*  MQDXP Structure                                                  */
 /*********************************************************************/

 typedef struct tagMQDXP {
   MQCHAR4  StrucId;         /* Structure identifier */
   MQLONG   Version;         /* Structure version number */
   MQLONG   ExitOptions;     /* Reserved */
   MQLONG   AppOptions;      /* Application options */
   MQLONG   Encoding;        /* Encoding required by application */
   MQLONG   CodedCharSetId;  /* Coded character-set identifier required
                                by application */
   MQLONG   DataLength;      /* Length in bytes of message data */
   MQLONG   CompCode;        /* Completion code */
   MQLONG   Reason;          /* Reason code qualifying CompCode */
   MQLONG   ExitResponse;    /* Response from exit */
   MQHCONN  Hconn;           /* Connection handle */
  } MQDXP;
 typedef MQDXP MQPOINTER PMQDXP;

 #define MQDXP_DEFAULT {MQDXP_STRUC_ID_ARRAY},\
                       MQDXP_VERSION_1,\
                       0L,\
                       0L,\
                       0L,\
                       0L,\
                       0L,\
                       MQCC_OK,\
                       MQRC_NONE,\
                       MQXDR_CONVERSION_FAILED,\
                       0L


 /*********************************************************************/
 /*  MQCHANNELEXIT -- Channel Exit Function Datatype                  */
 /*********************************************************************/

 typedef
   void MQENTRY MQCHANNELEXIT (
     PMQVOID  pChannelExitParms,   /* Channel exit parameter block */
     PMQVOID  pChannelDefinition,  /* Channel definition */
     PMQLONG  pDataLength,         /* Length of data */
     PMQLONG  pAgentBufferLength,  /* Length of agent buffer */
     PMQVOID  pAgentBuffer,        /* Agent buffer */
     PMQLONG  pExitBufferLength,   /* Length of exit buffer */
     PMQPTR   pExitBufferAddr);    /* Address of exit buffer */


 /*********************************************************************/
 /*  MQDATACONVEXIT -- Data-Conversion Exit Function Datatype         */
 /*********************************************************************/

 typedef
   void MQENTRY MQDATACONVEXIT (
     PMQDXP   pDataConvExitParms,  /* Data conversion exit parameter
                                      block */
     PMQMD    pMsgDesc,            /* Message descriptor */
     MQLONG   InBufferLength,      /* Length in bytes of InBuffer */
     PMQVOID  pInBuffer,           /* Buffer containing the unconverted
                                      message */
     MQLONG   OutBufferLength,     /* Length in bytes of OutBuffer */
     PMQVOID  pOutBuffer);         /* Buffer containing the converted
                                      message */


 /*********************************************************************/
 /*  MQXCNVC Function -- Convert Characters                           */
 /*********************************************************************/

 void MQENTRY MQXCNVC (
   MQHCONN  Hconn,          /* Connection handle */
   MQLONG   Options,        /* Options that control the action of
                               MQXCNVC */
   MQLONG   SourceCCSID,    /* Coded character set identifier of string
                               before conversion */
   MQLONG   SourceLength,   /* Length of string before conversion */
   PMQCHAR  pSourceBuffer,  /* String to be converted */
   MQLONG   TargetCCSID,    /* Coded character set identifier of string
                               after conversion */
   MQLONG   TargetLength,   /* Length of output buffer */
   PMQCHAR  pTargetBuffer,  /* String after conversion */
   PMQLONG  pDataLength,    /* Length of output string */
   PMQLONG  pCompCode,      /* Completion code */
   PMQLONG  pReason);       /* Reason code qualifying CompCode */


 #if defined(__cplusplus)
   }
 #endif

 #endif  /* End of header file */
